/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Resolve Common: ProxyContext Class
 * (Taken from GLite Data Transfer Agent)
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ProxyContext.h,v 1.2 2005/07/13 11:24:38 badino Exp $
 *  Release: $Name: glite-data-io-resolve-common_R_1_3_0_2 $
 *
 */
#ifndef GLITE_DATA_IO_RESOLVE_COMMON_PROXYCONTEXT_H_
#define GLITE_DATA_IO_RESOLVE_COMMON_PROXYCONTEXT_H_

#include <string>

namespace glite   {
namespace io      {
namespace resolve {
namespace common  {
    
/**
 * ProxyContext: wrapper class to set the environment variable with the 
 * proxy credentail and restore to the previous state when the object goes out 
 * of scope. 
 * Note: it doesn't work on a multithreaded environment
 */
class ProxyContext{
public:
    /**
     * Constructor
     */
    explicit ProxyContext(const std::string& file_name);
    /**
     * Destructor
     */
    ~ProxyContext();
private:
    /**
     * Default Constructor. Not Implemented
     */
    ProxyContext();
    /**
     * Copy Constructor. Not Implemented
     */
    ProxyContext(const ProxyContext&);
    /**
     * Assignment Operator. Not Implemented
     */
    ProxyContext& operator=(const ProxyContext&);
private:
    /**
     * Old value of the environment variable X509_USER_KEY
     */
    std::string m_key;

    /**
     * Old value of the environment variable X509_USER_CERT
     */
    std::string m_cert;

    /**
     * Old value of the environment variable X509_USER_PROXY
     */
    std::string m_proxy;
    /**
     * Flag the indicates that the environment variable has been set
     */
    bool m_isSet;
};

} // End namespace common
} // End namespace resolve
} // End namespace io
} // End namespace glite

#endif //GLITE_DATA_IO_RESOLVE_COMMON_PROXYCONTEXT_H_
