/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Resolve Common module: SrmClient Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: SoapHelper.hxx,v 1.4 2005/05/10 17:08:39 badino Exp $
 *  Release: $Name: glite-data-io-resolve-common_R_1_3_0_2 $
 *
 * 
 */

#ifndef GLITE_DATA_IO_RESOLVE_COMMON_SOAPHELPER_HXX_
#define GLITE_DATA_IO_RESOLVE_COMMON_SOAPHELPER_HXX_

#include "glite/data/io/daemon/FileItem.hxx"
#include "glite/data/io/daemon/UserPrincipal.hxx"
#include "glite/data/io/resolve/common/ProxyContext.h"

#include <string>

namespace glite  {
namespace io     {   
namespace resolve{   
namespace common {   
  
/**
 * SoapHelper
 */
class SoapHelper {

public:

    typedef enum {
        SP_NONE = 0,
        SP_SSL  = 1,
        SP_GSI  = 2
    } SecureProtocol;
    
    /*
     * Set the secure protocol. Delegation will be perfomed according the 
	 * DisableDelegation Configuration Parameter
     */ 
    static ProxyContext * setSecureProtocol(void * s, SecureProtocol secure_protocol, const glite::io::UserPrincipal * user);

    /*
     * Set the secure protocol
     */ 
    static ProxyContext * setSecureProtocol(void * s, SecureProtocol secure_protocol, const glite::io::UserPrincipal * user, bool useDelegation);

    /*
     * Unset the secure protocol. Delegation Data will be cleaned up according 
	 * the DisableDelegation Configuration Parameter
     */ 
//    static void unsetSecureProtocol(const glite::io::UserPrincipal * user);

    /*
     * Unset the secure protocol
     */ 
//    static void unsetSecureProtocol(const glite::io::UserPrincipal * user,bool useDelegation);

private:

    /*
     * Constructor. Not Implemented
     */
    SoapHelper();
};

} // End namespace common
} // End namespace resolve
} // End namespace io
} // End namespace glite

#endif // GLITE_DATA_IO_RESOLVE_COMMON_SOAPHELPER_HXX_
