/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Resolve Common module: SrmClient Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: SrmClient.hxx,v 1.5 2005/10/12 12:10:29 sobreira Exp $
 *  Release: $Name: glite-data-io-resolve-common_R_1_3_0_2 $
 * 
 */

#ifndef GLITE_DATA_IO_RESOLVE_COMMON_SRMCLIENT_HXX_
#define GLITE_DATA_IO_RESOLVE_COMMON_SRMCLIENT_HXX_

#include "glite/data/io/daemon/fileresolve/IFileResolve.hxx"
#include <string>

namespace log4cpp{
    class Category;
}
namespace glite  {
namespace io     {   
namespace resolve{   
namespace common {   

/*
 * Forward Declaration
 */
class ProxyContext;  

/**
 * SrmClient: Common SRM client function for File Resolve plugin implementations
 */
class SrmClient {

public:
    
    /**
     * File Status Running
     */
    static const char * FILE_STATUS_RUNNING;
    
    /**
     * File Status Done
     */
    static const char * FILE_STATUS_DONE;
    
    /**
     * fileresolve Context
     */
    class Context : public glite::io::resolve::IFileResolve::Context{
    public:
    
        typedef enum {
            UNDEF_OPERATION = 0,
            GET_OPERATION   = 1,
            PUT_OPERATION   = 2,
        } OperationType;
        /**
         *  Get Request ID Property 
         */
        int getRequestId() const {return _requestId;}
        /**
         *  Get File ID Property 
         */
        int getFileId() const {return _fileId;}
        /**
         * Get the Operation Type Property
         * @return Operation Type Property
         */
        OperationType getOperationType() const {return _type;}
          
    protected:    
        friend class SrmClient;
              
        /**
         *  Set Request ID Property 
         */
        void setRequestId(int reqId){_requestId = reqId;}
        /**
         *  Set File ID Property 
         */
        void setFileId(int fId){_fileId = fId;}
        /**
         * Set the Operation Type Property
         * @param t [IN] the Operation Type Property
         */
        void setOperationType(OperationType t){_type = t;}
        /**
         * Constructor
         */
        Context(FileItem * f, const glite::io::UserPrincipal * u):IFileResolve::Context(f,u),
            _requestId(0),_fileId(0),_type(UNDEF_OPERATION){}
        /**
         * Destructor
         */
        virtual ~Context(){}
    private:
        int             _requestId;    
        int             _fileId;    
        OperationType   _type;

    };
       
public:

    /*
     * Constructor
     */
    SrmClient();
    
    /*
     * Destructor
     */
    virtual ~SrmClient();
    
    // -------------------------------------------------------------------------
    // SRM Common Functions
    // -------------------------------------------------------------------------
    
    /**
     * Check that the requested Protocol is supported
     * @return 0 if success
     */
    int checkProtocol();

    /**
     * Get a TURL from a SURL
     */
    int getTurlFromSurl(SrmClient::Context * ctx, bool getMode);

    /**
     * Delete a SURL
     */
    int deleteSurl(SrmClient::Context * ctx);

    /**
     * set File Transfer Status
     */
    int setFileStatus(SrmClient::Context * ctx, const char * status);
   
    /**
     * Generate a new SURL from an LFN. If no LFN is provided, it will use the GUID
     */
    int generateSurl(SrmClient::Context * ctx);
    
    /**
     * Check That SRM Service is running
     */
    int checkService();
    
    /**
     * Get SE Host Name
     */
    const char * getSeHostName() const;
    
    /**
     * Check if the SURL is local To the SE
     */
    bool isLocalSurl(const char * surl);
    
protected:

    /**
     * Initialize The Srm Service
     */
    ProxyContext * initSrmService(void * service,const glite::io::UserPrincipal * user);

private:

    /**
     * The Logger
     */
    class log4cpp::Category& _logger;
};

} // End namespace common
} // End namespace resolve
} // End namespace io
} // End namespace glite

#endif // GLITE_DATA_IO_RESOLVE_COMMON_SRMCLIENT_HXX_
